@@ -38,8 +38,8 @@ from .template import TemplateConfig
 
 
 class AppConfig(BaseModel):
-    """The parameters provided to the `Starlite` app are used to instantiate an instance, and then the instance is
-    passed to any callbacks registered to `on_app_init` in the order they are provided.
+    """The parameters provided to the ``Starlite`` app are used to instantiate an instance, and then the instance is
+    passed to any callbacks registered to ``on_app_init`` in the order they are provided.
 
     The final attribute values are used to instantiate the application object.
     """
@@ -48,7 +48,7 @@ class AppConfig(BaseModel):
         arbitrary_types_allowed = True
 
     after_exception: SingleOrList[AfterExceptionHookHandler]
-    """An application level [exception hook handler][starlite.types.AfterExceptionHookHandler] or list thereof.
+    """An application level :class:`exception hook handler <starlite.types.AfterExceptionHookHandler>` or list thereof.
 
     This hook is called after an exception occurs. In difference to exception handlers, it is not meant to return a
     response - only to process the exception (e.g. log it, send it to Sentry etc.).
@@ -57,20 +57,20 @@ class AppConfig(BaseModel):
     """A sync or async function executed after the route handler function returned and the response object has been
     resolved.
 
-    Receives the response object which may be any subclass of [Response][starlite.response.Response].
+    Receives the response object which may be any subclass of :class:`Response <starlite.response.Response>`.
     """
     after_response: Optional[AfterResponseHookHandler]
     """A sync or async function called after the response has been awaited. It receives the.
 
-    [Request][starlite.connection.Request] object and should not return any values.
+    :class:`Request <starlite.connection.Request>` object and should not return any values.
     """
     after_shutdown: SingleOrList[LifeSpanHookHandler]
-    """An application level [life-span hook handler][starlite.types.LifeSpanHookHandler] or list thereof.
+    """An application level :class:`life-span hook handler <starlite.types.LifeSpanHookHandler>` or list thereof.
 
     This hook is called during the ASGI shutdown, after all callables in the 'on_shutdown' list have been called.
     """
     after_startup: SingleOrList[LifeSpanHookHandler]
-    """An application level [life-span hook handler][starlite.types.LifeSpanHookHandler] or list thereof.
+    """An application level :class:`life-span hook handler <starlite.types.LifeSpanHookHandler>` or list thereof.
 
     This hook is called during the ASGI startup, after all callables in the 'on_startup' list have been called.
     """
@@ -79,28 +79,28 @@ class AppConfig(BaseModel):
     before_request: Optional[BeforeRequestHookHandler]
     """A sync or async function called immediately before calling the route handler. Receives the.
 
-    [Request][starlite.connection.Request] instance and any non-`None` return value is used for the response, bypassing
+    :class:`Request <starlite.connection.Request>` instance and any non-``None`` return value is used for the response, bypassing
     the route handler.
     """
     before_send: SingleOrList[BeforeMessageSendHookHandler]
-    """An application level [before send hook handler][starlite.types.BeforeMessageSendHookHandler] or list thereof.
+    """An application level :class:`before send hook handler <starlite.types.BeforeMessageSendHookHandler>` or list thereof.
 
     This hook is called when the ASGI send function is called.
     """
     before_shutdown: SingleOrList[LifeSpanHookHandler]
-    """An application level [life-span hook handler][starlite.types.LifeSpanHookHandler] or list thereof.
+    """An application level :class:`life-span hook handler <starlite.types.LifeSpanHookHandler>` or list thereof.
 
     This hook is called during the ASGI shutdown, before any callables in the 'on_shutdown' list have been called.
     """
     before_startup: SingleOrList[LifeSpanHookHandler]
-    """An application level [life-span hook handler][starlite.types.LifeSpanHookHandler] or list thereof.
+    """An application level :class:`life-span hook handler <starlite.types.LifeSpanHookHandler>` or list thereof.
 
     This hook is called during the ASGI startup, before any callables in the 'on_startup' list have been called.
     """
     cache_config: CacheConfig
     """Configures caching behavior of the application."""
     cache_control: Optional[CacheControlHeader]
-    """A `cache-control` header of type [CacheControlHeader][starlite.datastructures.CacheControlHeader] to add to route
+    """A ``cache-control`` header of type :class:`CacheControlHeader <starlite.datastructures.CacheControlHeader>` to add to route
     handlers of this app.
 
     Can be overridden by route handlers.
@@ -114,67 +114,67 @@ class AppConfig(BaseModel):
     csrf_config: Optional[CSRFConfig]
     """If set this enables the builtin CSRF middleware."""
     debug: bool
-    """If `True`, app errors rendered as HTML with a stack trace."""
+    """If ``True``, app errors rendered as HTML with a stack trace."""
     dependencies: Dict[str, Provide]
-    """A string keyed dictionary of dependency [Provider][starlite.datastructures.Provide] instances."""
+    """A string keyed dictionary of dependency :class:`Provider <starlite.datastructures.Provide>` instances."""
     etag: Optional[ETag]
-    """An `etag` header of type [ETag][starlite.datastructures.ETag] to add to route handlers of this app.
+    """An ``etag`` header of type :class:`ETag <starlite.datastructures.ETag>` to add to route handlers of this app.
 
     Can be overridden by route handlers.
     """
     exception_handlers: ExceptionHandlersMap
     """A dictionary that maps handler functions to status codes and/or exception types."""
     guards: List[Guard]
-    """A list of [Guard][starlite.types.Guard] callables."""
+    """A list of :class:`Guard <starlite.types.Guard>` callables."""
     logging_config: Optional[BaseLoggingConfig]
-    """An instance of [BaseLoggingConfig][starlite.config.logging.BaseLoggingConfig] subclass."""
+    """An instance of :class:`BaseLoggingConfig <starlite.config.logging.BaseLoggingConfig>` subclass."""
     middleware: List[Middleware]
-    """A list of [Middleware][starlite.types.Middleware]."""
+    """A list of :class:`Middleware <starlite.types.Middleware>`."""
     on_shutdown: List[LifeSpanHandler]
-    """A list of [LifeSpanHandler][starlite.types.LifeSpanHandler] called during application shutdown."""
+    """A list of :class:`LifeSpanHandler <starlite.types.LifeSpanHandler>` called during application shutdown."""
     on_startup: List[LifeSpanHandler]
-    """A list of [LifeSpanHandler][starlite.types.LifeSpanHandler] called during application startup."""
+    """A list of :class:`LifeSpanHandler <starlite.types.LifeSpanHandler>` called during application startup."""
     openapi_config: Optional[OpenAPIConfig]
-    """Defaults to [DEFAULT_OPENAPI_CONFIG][starlite.app.DEFAULT_OPENAPI_CONFIG]"""
+    """Defaults to :data:`DEFAULT_OPENAPI_CONFIG <starlite.app.DEFAULT_OPENAPI_CONFIG>`"""
     opt: Dict[str, Any]
-    """A string keyed dictionary of arbitrary values that can be accessed in [Guards][starlite.types.Guard] or wherever
-    you have access to [Request][starlite.connection.request.Request] or [ASGI Scope][starlite.types.Scope].
+    """A string keyed dictionary of arbitrary values that can be accessed in :class:`Guards <starlite.types.Guard>` or
+    wherever you have access to :class:`Request <starlite.connection.request.Request>` or :class:`ASGI Scope <starlite.types.Scope>`.
 
     Can be overridden by routers and router handlers.
     """
     parameters: ParametersMap
-    """A mapping of [Parameter][starlite.params.Parameter] definitions available to all application paths."""
+    """A mapping of :class:`Parameter <starlite.params.Parameter>` definitions available to all application paths."""
     plugins: List[PluginProtocol]
-    """List of [PluginProtocol][starlite.plugins.base.PluginProtocol]."""
+    """List of :class:`PluginProtocol <starlite.plugins.base.PluginProtocol>`."""
     request_class: Optional[Type[Request]]
-    """An optional subclass of [Request][starlite.connection.request.Request] to use for http connections."""
+    """An optional subclass of :class:`Request <starlite.connection.request.Request>` to use for http connections."""
     response_class: Optional[ResponseType]
     """A custom subclass of [starlite.response.Response] to be used as the app's default response."""
     response_cookies: ResponseCookies
     """A list of [Cookie](starlite.datastructures.Cookie] instances."""
     response_headers: ResponseHeadersMap
-    """A string keyed dictionary mapping [ResponseHeader][starlite.datastructures.ResponseHeader] instances."""
+    """A string keyed dictionary mapping :class:`ResponseHeader <starlite.datastructures.ResponseHeader>` instances."""
     route_handlers: List[ControllerRouterHandler]
-    """A required list of route handlers, which can include instances of [Router][starlite.router.Router], subclasses
+    """A required list of route handlers, which can include instances of :class:`Router <starlite.router.Router>`, subclasses
     of.
 
-    [Controller][starlite.controller.Controller] or any function decorated by the route handler decorators.
+    :class:`Controller <starlite.controller.Controller>` or any function decorated by the route handler decorators.
     """
     security: List[SecurityRequirement]
     """A list of dictionaries that will be added to the schema of all route handlers in the application. See.
 
-    [SecurityRequirement][pydantic_openapi_schema.v3_1_0.security_requirement.SecurityRequirement] for details.
+    :class:`SecurityRequirement <pydantic_openapi_schema.v3_1_0.security_requirement.SecurityRequirement>` for details.
     """
     static_files_config: SingleOrList[StaticFilesConfig]
-    """An instance or list of [StaticFilesConfig][starlite.config.StaticFilesConfig]."""
+    """An instance or list of :class:`StaticFilesConfig <starlite.config.StaticFilesConfig>`."""
     tags: List[str]
     """A list of string tags that will be appended to the schema of all route handlers under the application."""
     template_config: Optional[TemplateConfig]
-    """An instance of [TemplateConfig][starlite.config.TemplateConfig]."""
+    """An instance of :class:`TemplateConfig <starlite.config.TemplateConfig>`."""
     type_encoders: Optional[TypeEncodersMap] = None
     """A mapping of types to callables that transform them into types supported for serialization."""
     websocket_class: Optional[Type[WebSocket]]
-    """An optional subclass of [WebSocket][starlite.connection.websocket.WebSocket] to use for websocket connections."""
+    """An optional subclass of :class:`WebSocket <starlite.connection.websocket.WebSocket>` to use for websocket connections."""
 
     @validator("allowed_hosts", always=True)
     def validate_allowed_hosts(  # pylint: disable=no-self-argument
