@@ -1,5 +1,5 @@
 from inspect import cleandoc
-from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union, cast
+from typing import TYPE_CHECKING, Dict, List, Optional, Tuple, Union
 
 from pydantic_openapi_schema.v3_1_0.operation import Operation
 from pydantic_openapi_schema.v3_1_0.path_item import PathItem
@@ -11,7 +11,6 @@ from starlite.types.internal_types import PathParameterDefinition
 from starlite.utils.helpers import unwrap_partial
 
 if TYPE_CHECKING:
-    from pydantic import BaseModel
     from pydantic_openapi_schema.v3_1_0 import SecurityRequirement
 
     from starlite.handlers import HTTPRouteHandler
@@ -83,10 +82,11 @@ def create_path_item(
 ) -> PathItem:
     """Create a PathItem model for the given route parsing all http_methods into Operation Models."""
     path_item = PathItem()
+
     for http_method, handler_tuple in route.route_handler_map.items():
         route_handler, _ = handler_tuple
         if route_handler.include_in_schema:
-            handler_fields = cast("BaseModel", route_handler.signature_model).__fields__
+            handler_fields = route_handler.signature_model.fields() if route_handler.signature_model else {}
             parameters = (
                 create_parameter_for_handler(
                     route_handler=route_handler,
@@ -126,5 +126,6 @@ def create_path_item(
                 parameters=parameters,  # type: ignore[arg-type]
                 security=security,
             )
+
             setattr(path_item, http_method.lower(), operation)
     return path_item
